summaryrefslogtreecommitdiffstats
path: root/content/common/input
diff options
context:
space:
mode:
Diffstat (limited to 'content/common/input')
-rw-r--r--content/common/input/input_event.cc2
-rw-r--r--content/common/input/input_event.h4
-rw-r--r--content/common/input/input_param_traits_unittest.cc22
-rw-r--r--content/common/input/scoped_web_input_event.cc12
-rw-r--r--content/common/input/scoped_web_input_event.h8
-rw-r--r--content/common/input/web_input_event_traits.cc18
-rw-r--r--content/common/input/web_input_event_traits.h16
7 files changed, 41 insertions, 41 deletions
diff --git a/content/common/input/input_event.cc b/content/common/input/input_event.cc
index dd41278..93e9691 100644
--- a/content/common/input/input_event.cc
+++ b/content/common/input/input_event.cc
@@ -10,7 +10,7 @@ namespace content {
InputEvent::InputEvent() : is_keyboard_shortcut(false) {}
-InputEvent::InputEvent(const WebKit::WebInputEvent& web_event,
+InputEvent::InputEvent(const blink::WebInputEvent& web_event,
const ui::LatencyInfo& latency_info,
bool is_keyboard_shortcut)
: web_event(WebInputEventTraits::Clone(web_event)),
diff --git a/content/common/input/input_event.h b/content/common/input/input_event.h
index 50e6aec..4c13e06 100644
--- a/content/common/input/input_event.h
+++ b/content/common/input/input_event.h
@@ -11,7 +11,7 @@
#include "content/common/input/scoped_web_input_event.h"
#include "ui/events/latency_info.h"
-namespace WebKit {
+namespace blink {
class WebInputEvent;
}
@@ -21,7 +21,7 @@ namespace content {
class CONTENT_EXPORT InputEvent {
public:
InputEvent();
- InputEvent(const WebKit::WebInputEvent& web_event,
+ InputEvent(const blink::WebInputEvent& web_event,
const ui::LatencyInfo& latency_info,
bool is_keyboard_shortcut);
~InputEvent();
diff --git a/content/common/input/input_param_traits_unittest.cc b/content/common/input/input_param_traits_unittest.cc
index 3414ec8..df42fd6 100644
--- a/content/common/input/input_param_traits_unittest.cc
+++ b/content/common/input/input_param_traits_unittest.cc
@@ -15,7 +15,7 @@ namespace {
typedef ScopedVector<InputEvent> InputEvents;
-void AddTo(InputEvents& events, const WebKit::WebInputEvent& event) {
+void AddTo(InputEvents& events, const blink::WebInputEvent& event) {
events.push_back(new InputEvent(event, ui::LatencyInfo(), false));
}
@@ -119,30 +119,30 @@ TEST_F(InputParamTraitsTest, InitializedEvents) {
ui::LatencyInfo latency;
- WebKit::WebKeyboardEvent key_event;
- key_event.type = WebKit::WebInputEvent::RawKeyDown;
+ blink::WebKeyboardEvent key_event;
+ key_event.type = blink::WebInputEvent::RawKeyDown;
key_event.nativeKeyCode = 5;
events.push_back(new InputEvent(key_event, latency, false));
- WebKit::WebMouseWheelEvent wheel_event;
- wheel_event.type = WebKit::WebInputEvent::MouseWheel;
+ blink::WebMouseWheelEvent wheel_event;
+ wheel_event.type = blink::WebInputEvent::MouseWheel;
wheel_event.deltaX = 10;
latency.AddLatencyNumber(ui::INPUT_EVENT_LATENCY_BEGIN_RWH_COMPONENT, 1, 1);
events.push_back(new InputEvent(wheel_event, latency, false));
- WebKit::WebMouseEvent mouse_event;
- mouse_event.type = WebKit::WebInputEvent::MouseDown;
+ blink::WebMouseEvent mouse_event;
+ mouse_event.type = blink::WebInputEvent::MouseDown;
mouse_event.x = 10;
latency.AddLatencyNumber(ui::INPUT_EVENT_LATENCY_UI_COMPONENT, 2, 2);
events.push_back(new InputEvent(mouse_event, latency, false));
- WebKit::WebGestureEvent gesture_event;
- gesture_event.type = WebKit::WebInputEvent::GestureScrollBegin;
+ blink::WebGestureEvent gesture_event;
+ gesture_event.type = blink::WebInputEvent::GestureScrollBegin;
gesture_event.x = -1;
events.push_back(new InputEvent(gesture_event, latency, false));
- WebKit::WebTouchEvent touch_event;
- touch_event.type = WebKit::WebInputEvent::TouchStart;
+ blink::WebTouchEvent touch_event;
+ touch_event.type = blink::WebInputEvent::TouchStart;
touch_event.touchesLength = 1;
touch_event.touches[0].radiusX = 1;
events.push_back(new InputEvent(touch_event, latency, false));
diff --git a/content/common/input/scoped_web_input_event.cc b/content/common/input/scoped_web_input_event.cc
index d9d3e76..8cd6e8a3 100644
--- a/content/common/input/scoped_web_input_event.cc
+++ b/content/common/input/scoped_web_input_event.cc
@@ -8,12 +8,12 @@
#include "content/common/input/web_input_event_traits.h"
#include "third_party/WebKit/public/web/WebInputEvent.h"
-using WebKit::WebGestureEvent;
-using WebKit::WebInputEvent;
-using WebKit::WebKeyboardEvent;
-using WebKit::WebMouseEvent;
-using WebKit::WebMouseWheelEvent;
-using WebKit::WebTouchEvent;
+using blink::WebGestureEvent;
+using blink::WebInputEvent;
+using blink::WebKeyboardEvent;
+using blink::WebMouseEvent;
+using blink::WebMouseWheelEvent;
+using blink::WebTouchEvent;
namespace content {
diff --git a/content/common/input/web_input_event_traits.h b/content/common/input/web_input_event_traits.h
index dba5f9c..b3b6d07 100644
--- a/content/common/input/web_input_event_traits.h
+++ b/content/common/input/web_input_event_traits.h
@@ -14,14 +14,14 @@ namespace content {
// Utility class for performing operations on and with WebInputEvents.
class WebInputEventTraits {
public:
- static const char* GetName(WebKit::WebInputEvent::Type type);
- static size_t GetSize(WebKit::WebInputEvent::Type type);
- static ScopedWebInputEvent Clone(const WebKit::WebInputEvent& event);
- static void Delete(WebKit::WebInputEvent* event);
- static bool CanCoalesce(const WebKit::WebInputEvent& event_to_coalesce,
- const WebKit::WebInputEvent& event);
- static void Coalesce(const WebKit::WebInputEvent& event_to_coalesce,
- WebKit::WebInputEvent* event);
+ static const char* GetName(blink::WebInputEvent::Type type);
+ static size_t GetSize(blink::WebInputEvent::Type type);
+ static ScopedWebInputEvent Clone(const blink::WebInputEvent& event);
+ static void Delete(blink::WebInputEvent* event);
+ static bool CanCoalesce(const blink::WebInputEvent& event_to_coalesce,
+ const blink::WebInputEvent& event);
+ static void Coalesce(const blink::WebInputEvent& event_to_coalesce,
+ blink::WebInputEvent* event);
};
} // namespace content
diff --git a/content/common/input/scoped_web_input_event.h b/content/common/input/scoped_web_input_event.h
index c11356f..e25cc0c 100644
--- a/content/common/input/scoped_web_input_event.h
+++ b/content/common/input/scoped_web_input_event.h
@@ -9,18 +9,18 @@
#include "base/memory/scoped_ptr.h"
#include "content/common/content_export.h"
-namespace WebKit {
+namespace blink {
class WebInputEvent;
}
namespace content {
// WebKit::WebInputEvent does not provide a virtual destructor.
struct CONTENT_EXPORT WebInputEventDeleter {
WebInputEventDeleter();
- void operator()(WebKit::WebInputEvent* web_event) const;
+ void operator()(blink::WebInputEvent* web_event) const;
};
-typedef scoped_ptr<WebKit::WebInputEvent,
+typedef scoped_ptr<blink::WebInputEvent,
WebInputEventDeleter> ScopedWebInputEvent;
} // namespace content
@@ -9,18 +9,18 @@
}
namespace content {
-// WebKit::WebInputEvent does not provide a virtual destructor.
+// blink::WebInputEvent does not provide a virtual destructor.
struct CONTENT_EXPORT WebInputEventDeleter {
WebInputEventDeleter();
diff --git a/content/common/input/web_input_event_traits.cc b/content/common/input/web_input_event_traits.cc
index 2f2eb7f..48787a2 100644
--- a/content/common/input/web_input_event_traits.cc
+++ b/content/common/input/web_input_event_traits.cc
@@ -6,12 +6,12 @@
#include "base/logging.h"
-using WebKit::WebGestureEvent;
-using WebKit::WebInputEvent;
-using WebKit::WebKeyboardEvent;
-using WebKit::WebMouseEvent;
-using WebKit::WebMouseWheelEvent;
-using WebKit::WebTouchEvent;
+using blink::WebGestureEvent;
+using blink::WebInputEvent;
+using blink::WebKeyboardEvent;
+using blink::WebMouseEvent;
+using blink::WebMouseWheelEvent;
+using blink::WebTouchEvent;
namespace content {
namespace {
@@ -106,8 +106,8 @@ void Coalesce(const WebTouchEvent& event_to_coalesce, WebTouchEvent* event) {
WebTouchEvent old_event = *event;
*event = event_to_coalesce;
for (unsigned i = 0; i < event->touchesLength; ++i) {
- if (old_event.touches[i].state == WebKit::WebTouchPoint::StateMoved)
- event->touches[i].state = WebKit::WebTouchPoint::StateMoved;
+ if (old_event.touches[i].state == blink::WebTouchPoint::StateMoved)
+ event->touches[i].state = blink::WebTouchPoint::StateMoved;
}
}
@@ -237,7 +237,7 @@ const char* WebInputEventTraits::GetName(WebInputEvent::Type type) {
CASE_TYPE(TouchEnd);
CASE_TYPE(TouchCancel);
default:
// Must include default to let WebKit::WebInputEvent add new event types
// before they're added here.
DLOG(WARNING) <<
"Unhandled WebInputEvent type in WebInputEventTraits::GetName.\n";
@@ -237,7 +237,7 @@ const char* WebInputEventTraits::GetName(WebInputEvent::Type type) {
CASE_TYPE(TouchCancel);
default:
- // Must include default to let WebKit::WebInputEvent add new event types
+ // Must include default to let blink::WebInputEvent add new event types
// before they're added here.
DLOG(WARNING) <<